import { InputType } from '@nestjs/graphql';
import {
  IsOptional,
  IsString,
  IsUrl,
  MaxLength,
  MinLength,
} from 'class-validator';

@InputType({ isAbstract: true })
export class CreateProjectInput {
  @IsString()
  @MaxLength(32)
  @MinLength(2)
  name: string;

  @IsString()
  @MaxLength(32)
  @MinLength(2)
  comment: string;

  @IsUrl({ protocols: ['ssh'], require_protocol: false })
  @MaxLength(256)
  sshUrl: string;

  @IsUrl()
  @IsOptional()
  @MaxLength(256)
  webUrl?: string;

  @IsString()
  @MaxLength(128)
  @MinLength(1)
  webHookSecret?: string;
}
